@@ -5,6 +5,7 @@
 \licence GPL3, see the file COPYING */
 
 #include "FacilityEngine.h"
+#include "ProductKey.h"
 
 #if defined (Q_OS_WIN32)
     #ifndef NOMINMAX
@@ -229,15 +230,21 @@ std::string FacilityEngine::simplifiedRemainingTime(const uint32_t &seconds) con
 /// \brief Return ultimate url, empty is not found or already ultimate
 std::string FacilityEngine::ultimateUrl() const
 {
-    #ifdef ULTRACOPIER_VERSION_ULTIMATE
-    return std::string();
-    #else
+    if(ProductKey::productKey->isUltimate())
+        return std::string();
+    else
+    {
         #if defined(Q_OS_WIN32) || defined(Q_OS_MAC)
-        return "http://ultracopier.first-world.info/shop.html";
+        return "https://shop.first-world.info/";
         #else
         return std::string();
         #endif
-    #endif
+    }
+}
+
+bool FacilityEngine::isUltimate() const
+{
+    return ProductKey::productKey->isUltimate();
 }
 
 /// \brief Return the software name
