@@ -1,8 +1,7 @@
 /** \file Variable.h
 \brief Define the environment variable
 \author alpha_one_x86
-\version 0.3
-\date 2010 */
+\licence GPL3, see the file COPYING */
 
 #ifndef VARIABLE_H
 #define VARIABLE_H
