@@ -18,6 +18,11 @@ void OptionsWidget::setAllDllIsImportant(bool allDllIsImportant)
     ui->allDllIsImportant->setChecked(allDllIsImportant);
 }
 
+void OptionsWidget::setAllUserIsImportant(bool allDllIsImportant)
+{
+    ui->allDllIsImportant->setChecked(allDllIsImportant);
+}
+
 void OptionsWidget::setDebug(bool Debug)
 {
     ui->Debug->setChecked(Debug);
@@ -28,6 +33,11 @@ void OptionsWidget::on_allDllIsImportant_toggled(bool checked)
     emit sendAllDllIsImportant(checked);
 }
 
+void OptionsWidget::on_allUserIsImportant_toggled(bool checked)
+{
+    emit sendAllUserIsImportant(checked);
+}
+
 void OptionsWidget::retranslate()
 {
     ui->retranslateUi(this);
