@@ -54,7 +54,8 @@ Themes::Themes(const bool &alwaysOnTop,
                FacilityInterface * facilityEngine,
                const bool &moreButtonPushed,
                const bool &minimizeToSystray,
-               const bool &startMinimized) :
+               const bool &startMinimized,
+               const bool &savePosition) :
     ui(new Ui::interfaceCopy()),
     uiOptions(new Ui::themesOptions())
 {
@@ -89,6 +90,9 @@ Themes::Themes(const bool &alwaysOnTop,
     //uiOptions->setupUi(ui->tabWidget->widget(ui->tabWidget->count()-1));
     uiOptions->labelStartWithMoreButtonPushed->setVisible(false);
     uiOptions->checkBoxStartWithMoreButtonPushed->setVisible(false);
+    uiOptions->labelSavePosition->setVisible(false);
+    uiOptions->savePosition->setVisible(false);
+    uiOptions->savePosition->setChecked(savePosition);
     uiOptions->label_Slider_speed->setVisible(false);
     uiOptions->SliderSpeed->setVisible(false);
     uiOptions->label_SpeedMaxValue->setVisible(false);
@@ -293,7 +297,8 @@ Themes::Themes(const bool &alwaysOnTop,
     uiOptions->labelAlwaysOnTop->hide();
     uiOptions->alwaysOnTop->hide();
     #endif*/
-    #ifdef ULTRACOPIER_VERSION_ULTIMATE
+    if(facilityEngine->isUltimate())
+    {
         #ifdef SUPERCOPIER
             ui->ad_ultimate->setText(tr("%1 is deprecated, Use %2").arg("<span style=\"color:#ee0000\">Super</span><span style=\"color:#0000cc\">Copier</span>").arg("<a href=\"http://ultracopier.first-world.info/\">Ultracopier</a>"));
         #else
@@ -303,12 +308,14 @@ Themes::Themes(const bool &alwaysOnTop,
                 ui->ad_ultimate->hide();
             #endif
         #endif
-    #else
-    QString ultimateUrl=QString::fromStdString(facilityEngine->ultimateUrl());
-    if(ultimateUrl.isEmpty())
-        ui->ad_ultimate->hide();
+    }
     else
-        ui->ad_ultimate->setText(
+    {
+        QString ultimateUrl=QString::fromStdString(facilityEngine->ultimateUrl());
+        if(ultimateUrl.isEmpty())
+            ui->ad_ultimate->hide();
+        else
+            ui->ad_ultimate->setText(
                     #ifdef SUPERCOPIER
                     tr("%1 is deprecated, Use %2").arg("<span style=\"color:#ee0000\">Super</span><span style=\"color:#0000cc\">copier</span>").arg("<a href=\"http://ultracopier.first-world.info/\">Ultracopier</a><br />")+
                     #endif
@@ -316,7 +323,7 @@ Themes::Themes(const bool &alwaysOnTop,
                     tr("This will be the last version for Mac, but you can compile from source")+
                     #endif
                     QStringLiteral("<a href=\"%1\">%2</a>").arg(ultimateUrl).arg(tr("Buy the Ultimate version to fund development")));
-    #endif
+    }
 
     #ifdef SUPERCOPIER
     uiOptions->labelDualProgression->hide();
@@ -1195,8 +1202,15 @@ void Themes::dropEvent(QDropEvent *event)
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"hasUrls");
         std::vector<std::string> urls;
+        unsigned int index=0;
         foreach (QUrl url, mimeData->urls())
-            urls.push_back(url.toString().toStdString());
+        {
+            const std::string &urlString=url.toString().toStdString();
+            if(index<99)
+                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,urlString);
+            urls.push_back(urlString);
+            index++;
+        }
         emit urlDropped(urls);
         event->acceptProposedAction();
     }
@@ -1495,3 +1509,4 @@ void Themes::on_exportErrorToTransferList_clicked()
 {
     emit exportErrorIntoTransferList();
 }
+
